From b4f8838b15342670c31753a484abf0129e3c9653 Mon Sep 17 00:00:00 2001
From: jcduff <jcduff@localhost>
Date: Thu, 23 Oct 2008 14:04:24 +0000
Subject: [PATCH] The commit will bring the following features :     - An updated version of the underlying database. BDB JE 3.3 is now used.     - Attribute API refactoring providing a better abstraction and offering improved performances.     - A new GUI called the Control-Panel to replace the Status-Panel: the specifications for this       GUI are available on OpenDS Wiki and contains a link to a mockup.        See <https://www.opends.org/wiki/page/ControlPanelUISpecification>.     - Some changes in the replication protocol to implement "Assured Replication Mode". The        specifications are on OpenDS Wiki at <https://www.opends.org/wiki/page/AssuredMode> and section 7       described some of the replication changes required to support this. Assured Replication is not finished,       but the main replication protocol changes to support it are done. As explained by Gilles on an email on       the Dev mailing list (http://markmail.org/message/46rgo3meq3vriy4a), with these changes the newer versions       of OpenDS may not be able to replicate with OpenDS 1.0 instances.     - Support for Service Tags on the platforms where the functionality is available and enabled. Specifications       are published at <https://www.opends.org/wiki/page/OpenDSServiceTagEnabled>. For more information on       Service Tags see <http://wikis.sun.com/display/ServiceTag/Sun+Service+Tag+FAQ>.     - The Admin Connector service. In order to provide agentry of the OpenDS server at any time, a new service       has been added, dedicated to the administration, configuration and monitoring of the server.       An overview of the Admin Connector service and it's use is available on the       OpenDS wiki <https://www.opends.org/wiki/page/ManagingAdministrationTrafficToTheServer>     - Updates to the various command line tools to support the Admin Connector service.     - Some internal re-architecting of the server to put the foundation of future developments such as virtual       directory services. The new NetworkGroups and WorkFlow internal services which have been specified in       <https://www.opends.org/wiki/page/BasicOperationRoutingThroughNetworkGroup> are now implemented.     - Many bug fixes...

---
 opendj-sdk/opends/src/server/org/opends/server/api/Backend.java |   78 +++++++++++++++++++--------------------
 1 files changed, 38 insertions(+), 40 deletions(-)

diff --git a/opendj-sdk/opends/src/server/org/opends/server/api/Backend.java b/opendj-sdk/opends/src/server/org/opends/server/api/Backend.java
index d598a0b..12fa4cd 100644
--- a/opendj-sdk/opends/src/server/org/opends/server/api/Backend.java
+++ b/opendj-sdk/opends/src/server/org/opends/server/api/Backend.java
@@ -284,7 +284,7 @@
    *          {@code false} if not.
    */
   public boolean isIndexed(AttributeType attributeType,
-                           MatchingRule matchingRule)
+                           MatchingRule<?> matchingRule)
   {
     return false;
   }
@@ -379,7 +379,7 @@
           return false;
         }
 
-        MatchingRule matchingRule;
+        MatchingRule<?> matchingRule;
         String matchingRuleID = filter.getMatchingRuleID();
         if (matchingRuleID != null)
         {
@@ -545,54 +545,52 @@
 
   /**
    * Replaces the specified entry with the provided entry in this
-   * backend.  The backend must ensure that an entry already exists
-   * with the same DN as the provided entry.  The caller must hold a
+   * backend. The backend must ensure that an entry already exists
+   * with the same DN as the provided entry. The caller must hold a
    * write lock on the DN of the provided entry.
    *
    * @param  entry            The new entry to use in place of the
    *                          existing entry with the same DN.
    * @param  modifyOperation  The modify operation with which this
    *                          action is associated.  This may be
    *                          {@code null} for modifications performed
    *                          internally.
    *
    * @throws  DirectoryException  If a problem occurs while trying to
    *                              replace the entry.
    *
    * @throws CanceledOperationException  If this backend noticed and
    *                                       reacted to a request to
    *                                       cancel or abandon the
    *                                       modify operation.
    */
-  public abstract void replaceEntry(Entry entry,
-                                    ModifyOperation modifyOperation)
-         throws DirectoryException, CanceledOperationException;
+  public abstract void replaceEntry(Entry oldEntry, Entry newEntry,
+      ModifyOperation modifyOperation) throws DirectoryException,
+      CanceledOperationException;
 
 
 
   /**
    * Moves and/or renames the provided entry in this backend, altering
-   * any subordinate entries as necessary.  This must ensure that an
+   * any subordinate entries as necessary. This must ensure that an
    * entry already exists with the provided current DN, and that no
-   * entry exists with the target DN of the provided entry.  The
-   * caller must hold write locks on both the current DN and the new
-   * DN for the entry.
+   * entry exists with the target DN of the provided entry. The caller
+   * must hold write locks on both the current DN and the new DN for
+   * the entry.
    *
-   * @param  currentDN          The current DN of the entry to be
-   *                            replaced.
-   * @param  entry              The new content to use for the entry.
-   * @param  modifyDNOperation  The modify DN operation with which
-   *                            this action is associated.  This may
-   *                            be {@code null} for modify DN
-   *                            operations performed internally.
-   *
-   * @throws  DirectoryException  If a problem occurs while trying to
-   *                              perform the rename.
-   *
-   * @throws CanceledOperationException  If this backend noticed and
-   *                                       reacted to a request to
-   *                                       cancel or abandon the
-   *                                       modify DN operation.
+   * @param currentDN
+   *          The current DN of the entry to be replaced.
+   * @param entry
+   *          The new content to use for the entry.
+   * @param modifyDNOperation
+   *          The modify DN operation with which this action is
+   *          associated. This may be {@code null} for modify DN
+   *          operations performed internally.
+   * @throws DirectoryException
+   *           If a problem occurs while trying to perform the rename.
+   * @throws CanceledOperationException
+   *           If this backend noticed and reacted to a request to
+   *           cancel or abandon the modify DN operation.
    */
   public abstract void renameEntry(DN currentDN, Entry entry,
                             ModifyDNOperation modifyDNOperation)
@@ -545,54 +545,52 @@
    * write lock on the DN of the provided entry.
    *
-   * @param  entry            The new entry to use in place of the
-   *                          existing entry with the same DN.
-   * @param  modifyOperation  The modify operation with which this
-   *                          action is associated.  This may be
-   *                          {@code null} for modifications performed
-   *                          internally.
-   *
-   * @throws  DirectoryException  If a problem occurs while trying to
-   *                              replace the entry.
-   *
-   * @throws CanceledOperationException  If this backend noticed and
-   *                                       reacted to a request to
-   *                                       cancel or abandon the
-   *                                       modify operation.
+   * @param oldEntry
+   *          The original entry that is being replaced.
+   * @param newEntry
+   *          The new entry to use in place of the existing entry with
+   *          the same DN.
+   * @param modifyOperation
+   *          The modify operation with which this action is
+   *          associated. This may be {@code null} for modifications
+   *          performed internally.
+   * @throws DirectoryException
+   *           If a problem occurs while trying to replace the entry.
+   * @throws CanceledOperationException
+   *           If this backend noticed and reacted to a request to
+   *           cancel or abandon the modify operation.
    */

--
Gitblit v1.10.0